==> nmrium-0.49.0.tgz: package/lib/component/panels/IntegralsPanel/IntegralPanel.js <==
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { SvgNmrIntegrate, SvgNmrSum } from 'cheminfo-font';
import lodashGet from 'lodash/get';
import { useCallback, useMemo, useState, useRef, memo } from 'react';
import { ImLink } from 'react-icons/im';
import { useChartData } from '../../context/ChartContext';
import { useDispatch } from '../../context/DispatchContext';
import ActiveButton from '../../elements/ActiveButton';
import ToolTip from '../../elements/ToolTip/ToolTip';
import { useModal } from '../../elements/popup/Modal';
import useSpectrum from '../../hooks/useSpectrum';
import ChangeSumModal from '../../modal/changeSum/ChangeSumModal';
import { tablePanelStyle } from '../extra/BasicPanelStyle';
import DefaultPanelHeader, { createFilterLabel, } from '../header/DefaultPanelHeader';
import PreferencesHeader from '../header/PreferencesHeader';
import IntegralTable from './IntegralTable';
import IntegralsPreferences from './IntegralsPreferences';
import { useActiveSpectrumIntegralsViewState } from '../../hooks/useActiveSpectrumIntegralsViewState';
const style = css `
  .sum-button {
    width: 22px;
    height: 22px;
    display: flex;
    align-items: center;
    justify-content: center;
  }

  button {
    margin-right: 2px;
  }
`;
function IntegralPanelInner({ integrals, info, activeTab, xDomain, }) {
    const [filterIsActive, setFilterIsActive] = useState(false);
    const dispatch = useDispatch();
    const { showIntegralsValues } = useActiveSpectrumIntegralsViewState();
    const modal = useModal();
    const [isFlipped, setFlipStatus] = useState(false);
    const settingRef = useRef();
    function handleShowIntegralsValues() {
        dispatch({
            type: 'TOGGLE_INTEGRALS_VIEW_PROPERTY',
            payload: { key: 'showIntegralsValues' },
        });
    }
    const yesHandler = useCallback(() => {
        dispatch({ type: 'DELETE_INTEGRAL', payload: {} });
    }, [dispatch]);
    const handleDeleteAll = useCallback(() => {
        modal.showConfirmDialog({
            message: 'All records will be deleted, Are You sure?',
            buttons: [{ text: 'Yes', handler: yesHandler }, { text: 'No' }],
        });
    }, [modal, yesHandler]);
    const changeIntegralSumHandler = useCallback((options) => {
        dispatch({ type: 'CHANGE_INTEGRAL_SUM', payload: { options } });
    }, [dispatch]);
    const currentSum = useMemo(() => {
        return lodashGet(integrals, 'options.sum', null);
    }, [integrals]);
    const settingsPanelHandler = useCallback(() => {
        setFlipStatus(!isFlipped);
    }, [isFlipped]);
    const saveSettingHandler = useCallback(() => {
        settingRef.current.saveSetting();
        setFlipStatus(false);
    }, []);
    const handleOnFilter = useCallback(() => {
        setFilterIsActive(!filterIsActive);
    }, [filterIsActive]);
    const toggleConstantSumHandler = useCallback(() => {
        dispatch({ type: 'CHANGE_INTEGRALS_SUM_FLAG' });
    }, [dispatch]);
    const filteredData = useMemo(() => {
        function isInRange(from, to) {
            const factor = 10000;
            to = to * factor;
            from = from * factor;
            return ((to >= xDomain[0] * factor && from <= xDomain[1] * factor) ||
                (from <= xDomain[0] * factor && to >= xDomain[1] * factor));
        }
        if (info.dimension === 1 && integrals?.values) {
            const _integrals = filterIsActive
                ? integrals.values.filter((integral) => isInRange(integral.from, integral.to))
                : integrals.values;
            return _integrals.map((integral) => {
                return {
                    ...integral,
                    isConstantlyHighlighted: isInRange(integral.from, integral.to),
                };
            });
        }
        return [];
    }, [filterIsActive, info.dimension, integrals, xDomain]);
    const counter = integrals?.values?.length || 0;
    return (_jsxs("div", { css: [
            tablePanelStyle,
            style,
            isFlipped &&
                css `
            th {
              position: relative;
            }
          `,
        ], children: [!isFlipped && (_jsxs(DefaultPanelHeader, { counter: counter, counterLabel: createFilterLabel(counter, filterIsActive && filteredData?.length), onDelete: handleDeleteAll, deleteToolTip: "Delete All Integrals", onFilter: handleOnFilter, filterToolTip: filterIsActive ? 'Show all integrals' : 'Hide integrals out of view', showSettingButton: true, onSettingClick: settingsPanelHandler, children: [_jsx(ToolTip, { title: currentSum
                            ? `Change integration sum (${currentSum.toFixed(2)})`
                            : 'Change integration sum', popupPlacement: "right", children: _jsx(ChangeSumModal, { onSave: changeIntegralSumHandler, sumType: "integrals", currentSum: currentSum, sumOptions: integrals?.options, renderButton: (onClick) => (_jsx("button", { className: "sum-button", type: "button", onClick: onClick, children: _jsx(SvgNmrSum, {}) })) }) }), _jsx(ActiveButton, { className: "icon", popupTitle: "Fixed integration values", popupPlacement: "right", onClick: toggleConstantSumHandler, value: integrals?.options?.isSumConstant || false, children: _jsx(ImLink, {}) }), _jsx(ActiveButton, { popupTitle: showIntegralsValues
                            ? 'Hide integrals values'
                            : 'Show integrals values', popupPlacement: "right", onClick: handleShowIntegralsValues, value: showIntegralsValues, children: _jsx(SvgNmrIntegrate, { style: { pointerEvents: 'none', fontSize: '12px' } }) })] })), isFlipped && (_jsx(PreferencesHeader, { onSave: saveSettingHandler, onClose: settingsPanelHandler })), _jsx("div", { className: "inner-container", children: !isFlipped ? (_jsx(IntegralTable, { data: filteredData, info: info, activeTab: activeTab })) : (_jsx(IntegralsPreferences, { ref: settingRef })) })] }));
}
const MemoizedIntegralPanel = memo(IntegralPanelInner);
const emptyData = { integrals: {}, info: {} };
export default function IntegralPanel() {
    const { xDomain, view: { spectra: { activeTab }, }, } = useChartData();
    const { integrals, info } = useSpectrum(emptyData);
    return (_jsx(MemoizedIntegralPanel, { integrals,
        info,
        xDomain,
        activeTab }));
}

==> nmrium-0.50.0.tgz: package/lib/component/panels/IntegralsPanel/IntegralPanel.js <==
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { SvgNmrIntegrate } from 'cheminfo-font';
import lodashGet from 'lodash/get';
import { useCallback, useMemo, useState, useRef, memo } from 'react';
import { ImLink } from 'react-icons/im';
import { Toolbar } from 'react-science/ui';
import { useChartData } from '../../context/ChartContext';
import { useDispatch } from '../../context/DispatchContext';
import { useModal } from '../../elements/popup/Modal';
import { useActiveSpectrumIntegralsViewState } from '../../hooks/useActiveSpectrumIntegralsViewState';
import useSpectrum from '../../hooks/useSpectrum';
import ChangeSumModal from '../../modal/changeSum/ChangeSumModal';
import { tablePanelStyle } from '../extra/BasicPanelStyle';
import DefaultPanelHeader, { createFilterLabel, } from '../header/DefaultPanelHeader';
import PreferencesHeader from '../header/PreferencesHeader';
import IntegralTable from './IntegralTable';
import IntegralsPreferences from './IntegralsPreferences';
function IntegralPanelInner({ integrals, info, activeTab, xDomain, }) {
    const [filterIsActive, setFilterIsActive] = useState(false);
    const dispatch = useDispatch();
    const { showIntegralsValues } = useActiveSpectrumIntegralsViewState();
    const modal = useModal();
    const [isFlipped, setFlipStatus] = useState(false);
    const settingRef = useRef();
    function handleShowIntegralsValues() {
        dispatch({
            type: 'TOGGLE_INTEGRALS_VIEW_PROPERTY',
            payload: { key: 'showIntegralsValues' },
        });
    }
    const yesHandler = useCallback(() => {
        dispatch({ type: 'DELETE_INTEGRAL', payload: {} });
    }, [dispatch]);
    const handleDeleteAll = useCallback(() => {
        modal.showConfirmDialog({
            message: 'All records will be deleted, Are You sure?',
            buttons: [{ text: 'Yes', handler: yesHandler }, { text: 'No' }],
        });
    }, [modal, yesHandler]);
    const changeIntegralSumHandler = useCallback((options) => {
        dispatch({ type: 'CHANGE_INTEGRAL_SUM', payload: { options } });
    }, [dispatch]);
    const currentSum = useMemo(() => {
        return lodashGet(integrals, 'options.sum', null);
    }, [integrals]);
    const settingsPanelHandler = useCallback(() => {
        setFlipStatus(!isFlipped);
    }, [isFlipped]);
    const saveSettingHandler = useCallback(() => {
        settingRef.current.saveSetting();
        setFlipStatus(false);
    }, []);
    const handleOnFilter = useCallback(() => {
        setFilterIsActive(!filterIsActive);
    }, [filterIsActive]);
    const toggleConstantSumHandler = useCallback(() => {
        dispatch({ type: 'CHANGE_INTEGRALS_SUM_FLAG' });
    }, [dispatch]);
    const filteredData = useMemo(() => {
        function isInRange(from, to) {
            const factor = 10000;
            to = to * factor;
            from = from * factor;
            return ((to >= xDomain[0] * factor && from <= xDomain[1] * factor) ||
                (from <= xDomain[0] * factor && to >= xDomain[1] * factor));
        }
        if (info.dimension === 1 && integrals?.values) {
            const _integrals = filterIsActive
                ? integrals.values.filter((integral) => isInRange(integral.from, integral.to))
                : integrals.values;
            return _integrals.map((integral) => {
                return {
                    ...integral,
                    isConstantlyHighlighted: isInRange(integral.from, integral.to),
                };
            });
        }
        return [];
    }, [filterIsActive, info.dimension, integrals, xDomain]);
    const counter = integrals?.values?.length || 0;
    return (_jsxs("div", { css: [
            tablePanelStyle,
            isFlipped &&
                css `
            th {
              position: relative;
            }
          `,
        ], children: [!isFlipped && (_jsx(DefaultPanelHeader, { counter: counter, counterLabel: createFilterLabel(counter, filterIsActive && filteredData?.length), onDelete: handleDeleteAll, deleteToolTip: "Delete All Integrals", onFilter: handleOnFilter, filterToolTip: filterIsActive ? 'Show all integrals' : 'Hide integrals out of view', showSettingButton: true, onSettingClick: settingsPanelHandler, children: _jsxs(Toolbar, { children: [_jsx(ChangeSumModal, { onSave: changeIntegralSumHandler, sumType: "integration", currentSum: currentSum, sumOptions: integrals?.options }), _jsx(Toolbar.Item, { icon: _jsx(ImLink, {}), title: 'Fixed integration values', onClick: toggleConstantSumHandler, active: integrals?.options?.isSumConstant || false }), _jsx(Toolbar.Item, { icon: _jsx(SvgNmrIntegrate, {}), title: showIntegralsValues
                                ? 'Hide integrals values'
                                : 'Show integrals values', onClick: handleShowIntegralsValues, active: showIntegralsValues })] }) })), isFlipped && (_jsx(PreferencesHeader, { onSave: saveSettingHandler, onClose: settingsPanelHandler })), _jsx("div", { className: "inner-container", children: !isFlipped ? (_jsx(IntegralTable, { data: filteredData, info: info, activeTab: activeTab })) : (_jsx(IntegralsPreferences, { ref: settingRef })) })] }));
}
const MemoizedIntegralPanel = memo(IntegralPanelInner);
const emptyData = { integrals: {}, info: {} };
export default function IntegralPanel() {
    const { xDomain, view: { spectra: { activeTab }, }, } = useChartData();
    const { integrals, info } = useSpectrum(emptyData);
    return (_jsx(MemoizedIntegralPanel, { integrals,
        info,
        xDomain,
        activeTab }));
}
